@@ -28,11 +28,30 @@ test.table
 	
 setMethod("print","anoint.fit",function(x,...) print(anointfit.table(x)))
 
+setGeneric("show", function(object) {})
 setMethod("show","anoint.fit",function(object) print(anointfit.table(object)))
 
-anointfit.summary <- function(object,...){
+anointfit.summary <- function(object, 
+                              type=c("all", "obo","uim","pim.exact","pim.approx"),
+                              ...) {
 	
-	test.table <- anointfit.table(object)
+  type = match.arg(type)
+  
+  test.table <- anointfit.table(object)
+	
+	rowN = switch(type,
+	             "all" = c(1, 2, 3, 4, 5, 6, 7), 
+	             "obo" = c(1,2), 
+	             "uim" = c(3), 
+	             "pim.exact" = c(4), 
+	             "pim.approx" = c(5))
+	
+	rowP = switch(type,
+	              "all" = c(1, 2, 3, 4),
+	              "obo" = c(1),
+	              "uim" = c(2),
+	              "pim.exact" = c(3),
+	              "pim.approx" = c(4))
 	
 	pvalues <- cbind(unlist(object@pvalues))
 	
@@ -45,9 +64,16 @@ anointfit.summary <- function(object,...){
 	
 	colnames(pvalues) <- "Global LRT (p-value)"
 
-	print(test.table)
+	print(test.table[rowN,,drop=F])
 	cat("\n")
-	print(pvalues)
+	print(pvalues[rowP,,drop=F])
+	
+	cat("\n")
+	if (type %in% c("uim", "obo")) {
+	  print(summary(object@fits[[type]]$fit[[1]]))
+	} else if (type %in% c("pim.exact", "pim.approx")) {
+	  print(pim.summary(object@fits[[type]]))
+	}
 	
 	invisible(list(tests=object@tests,pvalues=object@pvalues))	
 }
