@@ -8,19 +8,18 @@ setClass("anoint",
 
 
 anoint <- function(formula,data,family="binomial",select=NULL,nfolds=10,type.measure="deviance",keep.vars=NULL,na.action=na.omit,...){
-
-    data <- na.action(data[,all.vars(formula)]) # APPLY NA.ACTION
+  data <- na.action(data[,all.vars(formula)]) # APPLY NA.ACTION
 	f.anoint <- anoint.formula(formula,family=family)
 	trt.index <- which(names(data)==f.anoint@trt)
           
 	if(!is.null(select)){
 		if(select=="stepAIC"){
-			cat("Performing selection procedure for prognostic model...\n")
+			message("Performing selection procedure for prognostic model...\n")
 			update.formula <- select.stepAIC(f.anoint,trt.index,data,family,...)
 		}
 		else if(select=="glmnet"){
-			cat("Performing selection procedure for prognostic model...\n")
-			update.formula <- select.glmnet(f.anoint,trt.index,data,family,nfolds=nfolds,type.measure=type.measure,keep=keep.vars,...)
+		  message("Performing selection procedure for prognostic model...\n")
+			update.formula <- select.glmnet(object=f.anoint,index=trt.index,data=data,family=family,nfolds=nfolds,type.measure=type.measure,keep=keep.vars,...)
 		}		
 		else{
 			stop("Selection method not recognized.")
@@ -30,9 +29,9 @@ anoint <- function(formula,data,family="binomial",select=NULL,nfolds=10,type.mea
 		update.formula <- paste(update.formula,sep="",collapse="+")
 		formula <- paste(as.character(formula)[2],"~",
 		paste("(",update.formula,")*",f.anoint@trt,sep="",collapse=""),collapse="")
-		cat("Selected MIM:\n")
+		message("Selected MIM:\n")
 		formula <- formula(formula)
-		print(formula,showEnv=FALSE)
+		message(formula,showEnv=FALSE)
 		}
 	
 	new("anoint",
@@ -47,6 +46,7 @@ setMethod("print","anoint",definition=
 	function(x,...) print(x@formula)
 )
 
+setGeneric("show", function(object) {})
 setMethod("show","anoint",
 	function(object) print(object@formula)
 )
@@ -59,11 +59,10 @@ setMethod("summary","anoint",
 		response.index <- ncol(response.index)
 		candidates <- candidates[-(1:response.index)]
 		
-		cat(paste("MIM object with",length(candidates),"candidate response factors\n"))
-		cat(paste("Family:",object@formula@family,"\n"))
-		
-		cat("Candidates:\t",paste(candidates,collapse=", "),"\n")
-		
+	  cat(paste("MIM object with",length(candidates),"candidate response factors\n"))
+	  cat(paste("Family:",object@formula@family,"\n"))
+	  cat("Candidates:\t",paste(candidates,collapse=", "),"\n")
+	
 		print(object)
 		
 		formula.list <- list(
